@@ -3,6 +3,8 @@ from dm.exceptions import *
 from dm.dictionarywords import VISITOR_NAME
 from dm.strategy import FindProtectionObjects
 
+moddebug = False
+
 class BaseAccessController(object):
     """Template class for controlling access to protected objects.
 
@@ -54,7 +56,7 @@ class BaseAccessController(object):
             self.setProtectedObject(protectedObject)
             self.assertAccessAuthorised()
         except AccessIsAuthorised, inst:
-            if self.debug:
+            if moddebug and self.debug:
                 if self.person:
                     personName = self.person.name
                 else:
@@ -68,7 +70,7 @@ class BaseAccessController(object):
                 )
             return True
         except AccessNotAuthorised, inst:
-            if self.debug:
+            if moddebug and self.debug:
                 if self.person:
                     personName = self.person.name
                 else:
@@ -84,9 +86,9 @@ class BaseAccessController(object):
         return False
 
     def logAccessAttempt(self, person, actionName, protectedObject):
-        if self.debug:
-            if self.person:
-                personName = self.person.name
+        if moddebug and self.debug:
+            if person:
+                personName = person.name
             else:
                 personName = 'None'
             self.logger.debug(
@@ -124,17 +126,22 @@ class BaseAccessController(object):
         self.protectionObjects = findObjects.find()
 
     def assertAccessAuthorised(self):
-        raise AccessNotAuthorised("Access not authorised, by default.")
+        msg = "Access not authorised on any role and denied by default."
+        raise AccessNotAuthorised(msg)
 
     def isRoleAuthorised(self, role):
         if self.isPermissionGranted(role.grants):
-            if self.debug:
-                msg = "Access authorised by '%s' role." % role.name
+            if moddebug and self.debug:
+                msg = "Access authorised by '%s' associated role." % (
+                    role.name
+                )
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
-                msg = "Access not authorised by '%s' role." % role.name
+            if moddebug and self.debug:
+                msg = "Access not authorised by '%s' associated role." % (
+                    role.name
+                )
                 self.logger.debug(msg)
             return False
 
@@ -197,49 +204,49 @@ class SystemAccessController(BaseAccessController):
 
     def isPersonBarred(self):
         if self.isPermissionGranted(self.person.bars):
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access personally barred."
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access not personally barred."
                 self.logger.debug(msg)
             return False
 
     def isVisitorBarred(self):
         if self.isPermissionGranted(self.getVisitor().bars):
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access barred to visitor."
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access not barred to visitor."
                 self.logger.debug(msg)
             return False
 
     def isPersonAuthorisedPersonally(self):
         if self.isPermissionGranted(self.person.grants):
-            if self.debug:
-                msg = "Access personally authorised to person."
+            if moddebug and self.debug:
+                msg = "Access authorised by personal role."
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
-                msg = "Access not personally authorised to person."
+            if moddebug and self.debug:
+                msg = "Access not authorised by personal role."
                 self.logger.debug(msg)
             return False
 
     def isVisitorAuthorisedPersonally(self):
         if self.isPermissionGranted(self.getVisitor().grants):
-            if self.debug:
-                msg = "Access personally authorised to visitor."
+            if moddebug and self.debug:
+                msg = "Access authorised by visitor personal role."
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
-                msg = "Access not personally authorised to visitor."
+            if moddebug and self.debug:
+                msg = "Access not authorised by visitor personal role."
                 self.logger.debug(msg)
             return False
  
@@ -247,12 +254,12 @@ class SystemAccessController(BaseAccessController):
         systemRole = self.getPersonSystemRole()
         roleName = getattr(systemRole, 'name', '')
         if self.isPermissionGranted(systemRole.grants):
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access authorised by '%s' system role." % roleName
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access not authorised by '%s' system role." % roleName
                 self.logger.debug(msg)
             return False
@@ -260,12 +267,12 @@ class SystemAccessController(BaseAccessController):
     def isVisitorAuthorisedOnSystem(self):
         systemRole = self.getVisitorSystemRole()
         if self.isPermissionGranted(systemRole.grants):
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access authorised by visitor's system role."
                 self.logger.debug(msg)
             return True
         else:
-            if self.debug:
+            if moddebug and self.debug:
                 msg = "Access not authorised by visitor's system role."
                 self.logger.debug(msg)
             return False
