@@ -13,6 +13,7 @@ class AdministrationUtility(CommandLineUtility):
     
     def __init__(self, systemPath=None):
         CommandLineUtility.__init__(self) # old style class
+        self.appInstance= None
         self.interactive = 0
         self.prompt = '> '
         self.systemPath = systemPath
@@ -38,6 +39,7 @@ class AdministrationUtility(CommandLineUtility):
 
     def buildApplication(self):
         import dm.soleInstance
+        self.appInstance = dm.soleInstance.application
         
     def convertLineToArgs(self, line):
         unstrippedArgs = line.strip().split()
@@ -101,6 +103,10 @@ Dump service filesystem files
         from dm.migrate import DomainModelLoader
         dataLoader = DomainModelLoader()
         dataLoader.loadDataFromFile(dumpFilePath)
+        self.touchMigratedDomainModel()
+
+    def touchMigratedDomainModel(self):
+        pass
 
     def help_migrateload(self, line=None):
         usage = \
@@ -199,11 +205,12 @@ again in the same session.'''
 
     def do_upgrade(self, line=None):
         # TODO use system version to specify upgrade script used
+        # todo: Remove fs/db choice (who does one and not the other).
         args = self.convertLineToArgs(line)
         if len(args) != 1:
             self.help_upgrade(line)
             return 1
-        elif args[0] == 'data':
+        elif args[0] == 'fs':
             self.upgradeSystemServiceFilesystem()
             return 0
         elif args[0] == 'db':
@@ -222,9 +229,9 @@ again in the same session.'''
     def help_upgrade(self, line=None):
         usage = \
 '''upgrade <object>
-  object = data | db
+  object = fs | db
 
-Upgrade a KForge service (data and db)'''
+Upgrade a deployment (files and database)'''
         print usage
     
     def do_www(self, line=None):
@@ -242,11 +249,22 @@ Upgrade a KForge service (data and db)'''
             return 1
 
     def buildApacheConfig(self):
-        raise Exception, "Method not implemented."
-        
+        configBuilder = self.createApacheConfigBuilder()
+        configBuilder.buildConfigFile()
+
     def reloadApacheConfig(self):
-        raise Exception, "Method not implemented."
-      
+        configBuilder = self.createApacheConfigBuilder()
+        configBuilder.reloadConfig()
+
+    def createApacheConfigBuilder(self):
+        configBuilderClass = self.getApacheConfigBuilderClass()
+        configBuilder = configBuilderClass()
+        return configBuilder
+
+    def getApacheConfigBuilderClass(self):
+        from dm.apache.config import ApacheConfigBuilder
+        return ApacheConfigBuilder
+
     def help_www(self, line=None):
         help = 'www [ build | reload ]\n'
         help += '\tbuild: build web server configuration\n'
@@ -346,8 +364,10 @@ class UtilityRunner(object):
                 filePath = os.path.abspath(self.options.config_file_path)
                 os.environ[self.configFilePathEnvironVariableName] = filePath
             elif not os.environ.has_key(self.configFilePathEnvironVariableName):
+                envVarName = self.configFilePathEnvironVariableName
                 print 'ERROR. Please provide the path to the config file of' + \
-                      ' the service you wish to administer\n\n'
+                      ' the service you wish to administer.\n\n' + \
+                      'Or set the environment variable \'%s\'.\n\n' % envVarName
                 self.optionParser.print_help()
                 sys.exit(1)
             if self.options.system_path:
