@@ -139,8 +139,8 @@ class PersonAuthenticate(PersonCommand):
         reader = PersonRead(self.name)
         reader.execute()
         if not reader.person.isPassword(self.password):
-            message = "No authentication for '%s' with given password." % (
-                self.name
+            message = "Password digest mismatch for user '%s' (%s, %s)." % (
+                self.name, reader.person.password, reader.person.makeDigest(self.password)
             )
             self.raiseError(message)
         self.person = reader.person
