@@ -606,9 +606,9 @@ class MetaMapperAttribute(MetaBase):
         "Creates SQLObject columns for new SQLObject classes."
         if issubclass(self.dom.__class__, dm.dom.meta.String):
             if hasattr(self, 'default'):
-                return StringCol(default=self.default)
+                return UnicodeCol(default=self.default)
             else:
-                return StringCol()
+                return UnicodeCol()
         elif issubclass(self.dom.__class__, dm.dom.meta.DateTime):
             if hasattr(self, 'default'):
                 return DateTimeCol(default=self.default)
@@ -648,9 +648,9 @@ class MetaMapperAttribute(MetaBase):
         "Creates SQLObject columns for existing SQLObject classes."
         if issubclass(self.dom.__class__, dm.dom.meta.String):
             if hasattr(self, 'default'):
-                return StringCol(name=self.dbName, default=self.default)
+                return UnicodeCol(name=self.dbName, default=self.default)
             else:
-                return StringCol(name=self.dbName)
+                return UnicodeCol(name=self.dbName)
         elif issubclass(self.dom.__class__, dm.dom.meta.DateTime):
             if hasattr(self, 'default'):
                 return DateTimeCol(default=self.default)
@@ -1011,7 +1011,15 @@ class Mapper(SQLObject):
                     self.meta.domName
                 )
                 logger.debug(message)
-            self.syncUpdate()
+            try:
+                # Call SQLObject.
+                self.syncUpdate()
+            except Exception, inst:
+                message = "Failed to update RDBMS with %s mapper value." % (
+                    self.meta.domName
+                )
+                logger.error(message)
+                raise
 
     def coerceKwds(self, kwds):
         "Converting keyword names to database names."
