@@ -24,13 +24,18 @@ class SystemDictionary(dict):
         self.setConfigPathInDict()
         self.initTimezone()
         self.validateDictionaryWords()
+        self.assertWebkitEnvironment()
 
     def assertSystemName(self):
         if not self.getSystemName():
             raise Exception, "No system name!"
         
     def assertSystemEnvironment(self):
-        self.environment.assertDjangoSettingsModule()
+        pass
+
+    def assertWebkitEnvironment(self):
+        if self[WEBKIT_NAME] == 'django':
+            self.environment.assertDjangoSettingsModule()
         
     def setDefaultWords(self):
         self[PYTHONPATH]          = os.environ.get('PYTHONPATH', '')
@@ -47,6 +52,9 @@ class SystemDictionary(dict):
         self[NO_AUTH_COOKIE_NAME] = '%s_no_auth' % self[SYSTEM_NAME]
         self[LOG_LEVEL]           = 'INFO'
         self[WWW_PORT]            = '80'
+        self[NO_APACHE_RELOAD]    = '1'
+        self[APACHE_RELOAD_CMD]   = 'sudo /etc/init.d/apache2 reload'
+        self[APACHE_CONFIGTEST_CMD] = 'sudo /etc/init.d/apache2 configtest'
         self[URI_PREFIX]          = ''
         self[MEDIA_ROOT]          = ''
         self[MEDIA_HOST]          = ''
@@ -61,6 +69,7 @@ class SystemDictionary(dict):
         self[DB_MIGRATION_IN_PROGRESS] = ''
         self[DJANGO_SECRET_KEY]   = 'f*(d3d45zetsb3)$&2h5@lua()yc+kfn4w^dmrf_j1i(6jjkq'
         self[EDITOR]              = 'editor'
+        self[WEBKIT_NAME]         = 'django'
 
     def makeConfigFilePath(self):
         self.configFilePath = self.environment.getConfigFilePath()
