@@ -29,6 +29,9 @@ AUTH_COOKIE_NAME = 'auth_cookie_name'
 NO_AUTH_COOKIE_NAME = 'no_auth_cookie_name'
 AUTH_COOKIE_DOMAIN = 'auth_cookie_domain'
 APACHE_CONFIG_PATH = 'www.apache_config_file'
+NO_APACHE_RELOAD = 'www.no_reload_apache'
+APACHE_RELOAD_CMD = 'www.reload_apache'
+APACHE_CONFIGTEST_CMD = 'www.apache_configtest'
 URI_PREFIX = 'www.uri_prefix'
 MEDIA_ROOT = 'www.media_root'
 MEDIA_HOST = 'www.media_host'
@@ -38,6 +41,9 @@ TIMEZONE = 'environment.timezone'
 SKIP_EMAIL_SENDING = 'skip_email_sending'
 WWW_PORT = 'www.port'
 IMAGES_DIR_PATH = 'images_dir'
+WEBKIT_NAME = 'webkit_name'
 DJANGO_SECRET_KEY = 'django.secret_key'
 DJANGO_TEMPLATES_DIR = 'django.templates_dir'
+PYLONS_SECRET_KEY = 'pylons.secret_key'
+PYLONS_TEMPLATES_DIR = 'pylons.templates_dir'
 EDITOR = 'editor'
