@@ -1,21 +1,13 @@
 from dm.ioc import RequiredFeature
 from dm import dictionarywords
-from dm.debug import Debug
 
 dictionary = RequiredFeature('SystemDictionary')
 
 #
 ## Settings commonly defined in the system dictionary.
-
-DEBUG = True
-
-TEMPLATE_DIRS = (
-    dictionary[dictionarywords.DJANGO_TEMPLATES_DIR],
-)
-
+DEBUG = dictionary[dictionarywords.SYSTEM_MODE] != 'production',
+TEMPLATE_DIRS = (dictionary[dictionarywords.DJANGO_TEMPLATES_DIR],)
 TIME_ZONE = dictionary[dictionarywords.TIMEZONE]
-
-# todo: get this from the system dictionary
 SECRET_KEY = dictionary[dictionarywords.DJANGO_SECRET_KEY]
 
 #
