@@ -1,5 +1,6 @@
 """Package of domain model object classes."""
 
+from dm.ioc import RequiredFeature
 from dm.ioc import *
 from dm.dom.meta import *
 from dm.exceptions import *
@@ -25,7 +26,7 @@ class DomainBase(object):
 
 
 # Todo: Rename as AbstractRegister - this class is NOT a list. :-)
-class AbstractList(DomainBase): 
+class AbstractRegister(DomainBase): 
     """
     Supertype for domain model registers.
     Follows 'AbstractList' in 'Iterator (257)' [GoF].
@@ -86,7 +87,7 @@ class AbstractList(DomainBase):
         if moddebug and debug:
             message = "Retrieving from %s record for key: '%s'" % (self, key)
             if message == 'WeekEarmarkTemplate':
-                raise Exception, message
+                raise Exception(message)
             self.log.debug(message)
         return self.retrieveItem(key)
 
@@ -119,7 +120,7 @@ class RegisterIterator(object):
         return self
 
 
-class DomainObjectRegister(AbstractList):
+class DomainObjectRegister(AbstractRegister):
     "Supertype for concrete domain object registers."
 
     isStateful = False
@@ -169,12 +170,12 @@ class DomainObjectRegister(AbstractList):
             if item and self.isCached:
                 self.cacheItem(item)
             if not item:
-                message = "findDomainObject() returned: %s" % str(item)
+                message = "findDomainObject() returned: %s" % unicode(item)
                 raise StandardError(message)
         except StandardError, inst:
             msg = "No %s called '%s' found: %s" \
                 % (self.typeName, key, inst)
-            raise KforgeRegistryKeyError, msg
+            raise KforgeRegistryKeyError(msg)
         return item
 
     def create(self, *args, **kwds):
@@ -268,7 +269,7 @@ class DomainObjectRegister(AbstractList):
             if object.isChanged:
                 object.save()
         except KforgeDbError, inst:
-            raise KforgeDomError, inst
+            raise KforgeDomError(inst)
         else:
             return object
 
@@ -679,7 +680,7 @@ class DomainObject(DomainBase):
             raise DomainClassRegistrationError(message)
         if len(self.meta.attributesDeferred):
             message = "Class '%s' has mismatched (deferred) attributes: %s" % (
-                className, str(self.meta.attributesDeferred))
+                className, unicode(self.meta.attributesDeferred))
             raise DomainClassRegistrationError(message)
 
     def isClassRegistered(self, domainClass):
@@ -770,7 +771,7 @@ class DomainObject(DomainBase):
         "Raises onUpdate event."
         self.onUpdate()
         if debug:
-            message = "Updated %s: '%s'" % (
+            message = u"Updated %s: '%s'" % (
                 self.__class__.__name__,
                 self
             )
@@ -880,7 +881,7 @@ class DomainObject(DomainBase):
     # todo: rename to getLabel
     def getLabelValue(self):
         # default to register key value
-        return str(self.getRegisterKeyValue())
+        return unicode(self.getRegisterKeyValue())
 
     def getPersonalLabel(self):
         # default to basic label
