@@ -2,6 +2,8 @@
 Meta classes describe the DomainObject classes.
 """
 
+# Todo: Rename convertor to converter (spelling).
+
 from dm.ioc import *
 import md5
 import mx.DateTime
@@ -226,7 +228,7 @@ class MetaDomainAttr(BaseDomainMeta):
 
     def createValueRepr(self, domainObject):
         value = getattr(domainObject, self.name)
-        return str(value)
+        return unicode(value)
 
     def createLabelRepr(self, domainObject):
         return self.createValueRepr(domainObject)
@@ -281,11 +283,11 @@ class MetaDomainAttr(BaseDomainMeta):
     def duplicateTemporal(self):
         attrMeta = self.duplicateSelf()
         if self.isBitemporal:
-             attrMeta.isBitemporal = False
-             attrMeta.isBitemporalActual = True
-             attrMeta.isTemporal = True
+            attrMeta.isBitemporal = False
+            attrMeta.isBitemporalActual = True
+            attrMeta.isTemporal = True
         else:
-             attrMeta.isTemporal = False
+            attrMeta.isTemporal = False
         attrMeta.isRequired = self.isRequired
         return attrMeta
 
@@ -389,6 +391,7 @@ class Password(String):
         return attrValue
 
     def makeDigest(self, clearText):
+        clearText = unicode(clearText).encode('utf-8')
         return md5.new(clearText).hexdigest()
 
     def setAttributeValue(self, domainObject, attrValue):
@@ -524,7 +527,7 @@ class Integer(ValueObjectAttr):
 
     def createLabelRepr(self, domainObject):
         value = getattr(domainObject, self.name)
-        return str(value)
+        return unicode(value)
 
 
 class BLOB(ValueObjectAttr):
@@ -608,7 +611,7 @@ class DomainObjectAssociation(MetaDomainAttr):
                 choices.append(choice)
         except Exception, inst:
             message = "Couldn't get choices for %s: %s" % (
-               self.typeName, str(inst)
+               self.typeName, unicode(inst)
             )
             raise Exception(message)
         return choices
@@ -671,9 +674,9 @@ class DomainObjectRef(DomainObjectAssociation):
         if value == None:
             return ""
         elif value:
-            return str(value.getLabelValue())
+            return unicode(value.getLabelValue())
         else:
-            return str(value)
+            return unicode(value)
        
     def makeValueFromMultiValueDict(self, multiValueDict):
         refValue = multiValueDict[self.name]
@@ -873,10 +876,10 @@ class AssociateList(DomainObjectAssociation):
         register = self.getAssociationObjectRegister(domainObject)
         labelsList = []
         if self.isKeyDomainObject():
-            labelsList = [str(register.getRegisterKey(i).getLabelValue()) for i in register.getSortedList()]
+            labelsList = [unicode(register.getRegisterKey(i).getLabelValue()) for i in register.getSortedList()]
             labelsList = ", ".join(labelsList)
         else:
-            labelsList = [str(i.getLabelValue()) for i in register.getSortedList()]
+            labelsList = [unicode(i.getLabelValue()) for i in register.getSortedList()]
             labelsList = ", ".join(labelsList)
         return labelsList or "_"
 
@@ -889,10 +892,10 @@ class AssociateList(DomainObjectAssociation):
             valueLabel = {}
             if isKeyDomainObject:
                 value = registerKey.getRegisterKeyValue() 
-                label = str(registerKey.getLabelValue())
+                label = unicode(registerKey.getLabelValue())
             else:
                 value = registerKey
-                label = str(domainObject.getLabelValue())
+                label = unicode(domainObject.getLabelValue())
             valueLabel['value'] = value
             valueLabel['label'] = label
             valueLabel['associationObject'] = register[registerKey]
@@ -911,7 +914,7 @@ class AssociateList(DomainObjectAssociation):
                 namedValue = {}
                 keyValue = associatedObject.getRegisterKeyValue() 
                 namedValue['key'] = keyValue
-                labelValue = str(associatedObject.getLabelValue())
+                labelValue = unicode(associatedObject.getLabelValue())
                 namedValue['label'] = labelValue
                 namedValue['associatedObject'] = associatedObject
                 namedValue['associationObject'] = associationObject
@@ -921,7 +924,7 @@ class AssociateList(DomainObjectAssociation):
                 namedValue = {}
                 keyValue = associatedObject.getRegisterKeyValue() 
                 namedValue['key'] = keyValue
-                labelValue = str(associatedObject.getLabelValue())
+                labelValue = unicode(associatedObject.getLabelValue())
                 namedValue['label'] = labelValue
                 namedValue['associatedObject'] = associatedObject
                 namedValue['associationObject'] = associatedObject
@@ -939,7 +942,7 @@ class AssociateList(DomainObjectAssociation):
             associatedObjectKey = getattr(associationObject, self.key)
             if self.isKeyDomainObject():
                 associatedObjectKey = associatedObjectKey.getRegisterKeyValue()
-            if not str(associatedObjectKey) in associatedObjectKeys:
+            if not unicode(associatedObjectKey) in associatedObjectKeys:
                 associationObject.delete()
         # create where missing
         for associatedObjectKey in associatedObjectKeys:
