@@ -37,6 +37,9 @@ class Session(SimpleDatedObject):
         return md5.new(randomStr).hexdigest()
 
     def updateLastVisited(self):
-        self.lastVisited = mx.DateTime.now()
-        self.save()
-        
+        timeVisited = mx.DateTime.now()
+        # Operator works for mix of datetime.datetime and mx.DateTime.
+        if (timeVisited > self.lastVisited):
+            self.lastVisited = timeVisited
+            self.save()
+
