@@ -101,7 +101,7 @@ class State(SimpleNamedObject):
 
     def checkName(self):
         if not self.name:
-            raise Exception, "State has no name: %s" % self
+            raise Exception("State has no name: %s" % self)
 
     def createBehaviour(self):
         stateName = self.name
