@@ -42,7 +42,10 @@ class StatefulRegister(DomainObjectRegister):
         return self.initialiseWithState
 
     def getState(self, name):
-        return self.registry.states[name]
+        if name in self.registry.states:
+            return self.registry.states[name]
+        else:
+            return None
 
 
 class CompoundRegister(StatefulRegister):
@@ -211,17 +214,17 @@ class PagedCompoundRegister(CompoundRegister):
         return list
 
     def coerceKwds(self, kwds):
-        raise Exception, "Intermediate register isn't a proper domain object register."
+        raise Exception("Intermediate register isn't a proper domain object register.")
 
     #def getKeyName(self):
     #    raise Exception, "Intermediate register isn't a proper domain object register."
 
     def keys(self):
         if not self.pageKeys:
-            raise Exception, "No pageKeys method to get pageKeys register."
+            raise Exception("No pageKeys method to get pageKeys register.")
         pageKeyRegister = self.pageKeys()
         if not pageKeyRegister:
-            raise Exception, "No page key register."
+            raise Exception("No page key register.")
         return [pageKey for pageKey in pageKeyRegister]
         
     def retrieveItem(self, key):
@@ -324,7 +327,7 @@ class PagedAssociateList(Paged, AssociateList):
     def getAssociationObject(self, domainObject, keyValue):
         keyValues = keyValue.split('::')
         if len(keyValues) != 2:
-            raise Exception, "Only one page key allowed: %s" % keyValues
+            raise Exception("Only one page key allowed: %s" % keyValues)
         pageKeyValue = keyValues[0]
         objectKeyValue = keyValues[1]
 
@@ -333,8 +336,8 @@ class PagedAssociateList(Paged, AssociateList):
             pageKeyMeta = self.getPageKeyMetaAttribute()
             pageKeyClassName = pageKeyMeta.typeName
             pageKeyClass = self.registry.getDomainClass(pageKeyClassName)
-            pageKeyRegister = pageKeyClass.createRegister()
-            pageKey = pageKeyRegister[pageKeyValue]
+            pageRegister = pageKeyClass.createRegister()
+            pageKey = pageRegister[pageKeyValue]
         else:
             pageKey = pageKeyValue
         
@@ -343,8 +346,8 @@ class PagedAssociateList(Paged, AssociateList):
             objectKeyMeta = self.getKeyMetaAttribute()
             objectKeyClassName = objectKeyMeta.typeName
             objectKeyClass = self.registry.getDomainClass(objectKeyClassName)
-            objectKeyRegister = objectKeyClass.createRegister()
-            objectKey = associatedRegister[objectKeyValue]
+            objectRegister = objectKeyClass.createRegister()
+            objectKey = objectRegister[objectKeyValue]
         else:
             objectKey = objectKeyValue
             
