@@ -201,19 +201,23 @@ class DomainModelLoader(object):
                                 #)
                                 #print msg
                                 value = mappedValue
-                        if value.__class__ == unicode:
-                            # SQLObject doesn't handle unicode.
-                            try:
-                                value = str(value)
-                            except:
-                                msg = "Failed to convert unicode to str"
-                                msg += " for '%s' of %s %s: %s" % (
-                                    attr.name, className, objectId, value
-                                )
-                                self.logger.error(msg)
-                                msg = "Continuing with null string value."
-                                self.logger.info(msg)
-                                value = ""
+                        # Todo: Support for earlier versions of SQLObject,
+                        # if commenting the above line out stops it working,
+                        # but we need to start accepting unicode, really.
+                        #
+                        #if type(value) == unicode:
+                        #    # SQLObject doesn't handle unicode.
+                        #    try:
+                        #        value = str(value)
+                        #    except Exception, inst:
+                        #        msg = "Failed to convert unicode to str"
+                        #        msg += " for '%s' of %s %s: %s: %s" % (
+                        #            attr.name, className, objectId, value, inst
+                        #        )
+                        #        self.logger.error(msg)
+                        #        msg = "Continuing with null string value."
+                        #        self.logger.info(msg)
+                        #        value = ""
 
                         if attr.isDomainObjectRef and (attr.typeName==className):
                             reflexiveStrObjectData[attr.name] = value
