@@ -118,9 +118,9 @@ class FindProtectionObject(BaseStrategy):
         for name in protectedNames:
             if name in self.registry.protectionObjects:
                 return self.registry.protectionObjects[name]
-        raise Exception, "No protection object for %s (protected names: %s)" % (
+        raise Exception("No protection object for %s (protected names: %s)" % (
             self.protectedObject, protectedNames
-        )
+        ))
 
 
 class CreateProtectionObject(BaseStrategy):
