@@ -1,7 +1,8 @@
-import unittest
 import dm.timestest
+import dm.timepointtest
 import dm.strategytest
 import dm.environmenttest
+import dm.apachetest
 import dm.logtest
 import dm.debugtest
 import dm.dbtest
@@ -14,16 +15,20 @@ import dm.commandtest
 import dm.filesystemtest
 import dm.accesscontroltest
 import dm.applicationtest
+import dm.migratetest
 import dm.viewtest
 import dm.djangotest
-import dm.migratetest
+import dm.pylonstest
+import dm.datetimeconvertortest
 from dm.testunit import ApplicationTestSuite
 
 def suite():
     suites = [
         dm.timestest.suite(),
+        dm.timepointtest.suite(),
         dm.strategytest.suite(),
         dm.environmenttest.suite(),
+        dm.apachetest.suite(),
         dm.logtest.suite(),
         dm.debugtest.suite(),
         dm.dbtest.suite(),
@@ -33,12 +38,13 @@ def suite():
         dm.configtest.suite(),
         dm.dictionarytest.suite(),
         dm.commandtest.suite(),
-        #dm.filesystemtest.suite(),
         dm.accesscontroltest.suite(),
         dm.viewtest.suite(),
-        dm.applicationtest.suite(),
-        dm.djangotest.suite(),
         dm.migratetest.suite(),
+        dm.djangotest.suite(),
+        dm.pylonstest.suite(),
+        #dm.filesystemtest.suite(),
+        #dm.applicationtest.suite(),
     ]
     return ApplicationTestSuite(suites)
 
