@@ -1,9 +1,11 @@
 from dm.ioc import *
 from dm.exceptions import KforgeCommandError
-from dm.dictionarywords import WEBKIT_NAME
 from dm.webkit import ValidationError
 from dm.webkit import Manipulator
 from dm.webkit import htmlescape
+from dm.webkit import webkitName, webkitVersion
+if webkitName == 'django' and webkitVersion == '1.0':
+    from dm.webkit import SortedDict
 import re
 import dm.webkit
 
@@ -18,18 +20,27 @@ class BaseManipulator(Manipulator):
 
     sizeSelectMultiple = 4
 
+    base_fields = []  # Django 1.0.
+
     def getValidationErrors(self, data):
-        try:
-            return self.get_validation_errors(data)
-        except Exception, inst:
-            msg = "Exception in 'get_validation_errors' with data %s: %s" % (
-                data, inst
-            )
-            self.logger.error(msg)
-            raise
+            if webkitName == 'django' and webkitVersion == '1.0':
+                self._errors = None
+                self.data = data
+                self.is_bound = True
+                return self.errors
+            else:
+                try:
+                    return self.get_validation_errors(data)
+                except Exception, inst:
+                    msg = "Exception in 'getValidationErrors' with data %s: %s" % (
+                        data, inst
+                    )
+                    self.logger.error(msg)
+                    raise
 
     def decodeHtml(self, data):
-        return self.do_html2python(data)
+        if webkitName == 'django' and webkitVersion == '0.96':
+            return self.do_html2python(data)
 
     def isTwoCharsMin(self, field_data, all_data):
         self.isTooShort(field_data, 2)
@@ -63,6 +74,8 @@ class DomainObjectManipulator(BaseManipulator):
 
     def __init__(self, objectRegister,
             domainObject=None, fieldNames=[], client=None):
+        if webkitName == 'django' and webkitVersion == '1.0':
+            super(DomainObjectManipulator, self).__init__()
         self.client = client
         self.objectRegister = objectRegister
         self.metaObject = self.objectRegister.getDomainClassMeta()
@@ -70,15 +83,20 @@ class DomainObjectManipulator(BaseManipulator):
         self.fieldNames = fieldNames
         if self.fieldNames == None:
             self.fieldNames = []
-        self.fields = []
+        if webkitName == 'django' and webkitVersion == '1.0':
+            self.fields = SortedDict()
+        else:
+            self.fields = []
         msg = "Building manipulator fields for %s..." % (
             self.__class__.__name__
         )
         self.logger.debug(msg)
         self.buildFields()
         if self.fieldNames == []:
-            for field in self.fields:
-                self.fieldNames.append(field.field_name)
+            if webkitName == 'django' and webkitVersion == '1.0':
+                self.fieldNames = self.fields.keys()
+            else:
+                self.fieldNames = [field.field_name for field in self.fields]
         msg = "Built '%s' manipulator with field names: %s" % (
             self.__class__.__name__, ", ".join(self.fieldNames)
         )
@@ -116,12 +134,16 @@ class DomainObjectManipulator(BaseManipulator):
         field = None
         isFieldRequired = metaAttr.isRequired
         self.logger.debug("Building manipulator field: %s" % metaAttr.name)
-        webkitName = self.dictionary[WEBKIT_NAME]
 
         if metaAttr.isAssociateList:
             countChoices = metaAttr.countChoices(self.domainObject)
             choices = metaAttr.getAllChoices(self.domainObject)
-            if webkitName == 'django':
+            if webkitName == 'django' and webkitVersion == '1.0':
+                field = self.webkit.ChoiceField(
+                    required=isFieldRequired,
+                    choices=choices,
+                )
+            elif webkitName == 'django' and webkitVersion == '0.96':
                 field = self.webkit.SelectMultipleField(
                     field_name=metaAttr.name,
                     is_required=isFieldRequired,
@@ -140,7 +162,12 @@ class DomainObjectManipulator(BaseManipulator):
             if True or countChoices <= 50:
                 choices = metaAttr.getAllChoices(self.domainObject)
                 choices = [('', '-- select option --')] + choices
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    field = self.webkit.ChoiceField(
+                        required=isFieldRequired,
+                        choices=choices,
+                    )
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.SelectField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -151,7 +178,9 @@ class DomainObjectManipulator(BaseManipulator):
                         metaAttr.name,
                     )
             else:  # need to find a way to only do this for string keys
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.TextField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -164,7 +193,11 @@ class DomainObjectManipulator(BaseManipulator):
         elif metaAttr.isValueObject():
             if metaAttr.typeName == 'String':
                 if metaAttr.name[0:5] == 'email':
-                    if webkitName == 'django':
+                    if webkitName == 'django' and webkitVersion == '1.0':
+                        field = self.webkit.EmailField(
+                            required=isFieldRequired,
+                        )
+                    elif webkitName == 'django' and webkitVersion == '0.96':
                         field = self.webkit.EmailField(
                             field_name=metaAttr.name,
                             is_required=isFieldRequired,
@@ -176,7 +209,11 @@ class DomainObjectManipulator(BaseManipulator):
                             size=36
                         )
                 else:
-                    if webkitName == 'django':
+                    if webkitName == 'django' and webkitVersion == '1.0':
+                        field = self.webkit.Field(
+                            required=isFieldRequired,
+                        )
+                    elif webkitName == 'django' and webkitVersion == '0.96':
                         field = self.webkit.TextField(
                             field_name=metaAttr.name,
                             is_required=isFieldRequired,
@@ -188,7 +225,9 @@ class DomainObjectManipulator(BaseManipulator):
                         )
                 
             elif metaAttr.typeName == 'Text':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.LargeTextField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -201,7 +240,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'MarkdownText':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.LargeTextField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -214,7 +255,12 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'Password':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    field = self.webkit.Field(
+                        required=isFieldRequired,
+                        widget=dm.webkit.widgets.PasswordInput,
+                    )
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.PasswordField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -225,7 +271,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'Integer':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.IntegerField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -236,7 +284,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'Boolean':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.CheckboxField(
                         field_name=metaAttr.name
                         # doesn't accept 'is_required' parameter
@@ -247,7 +297,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'Url':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.URLField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -258,7 +310,11 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'DateTime':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    field = self.webkit.DateTimeField(
+                        required=isFieldRequired,
+                    )
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.DatetimeField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -269,7 +325,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'Date':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.DateField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -280,7 +338,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             elif metaAttr.typeName == 'RDate':
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.RDateField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -291,7 +351,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
             else:
-                if webkitName == 'django':
+                if webkitName == 'django' and webkitVersion == '1.0':
+                    raise Exception("No field yet.")
+                elif webkitName == 'django' and webkitVersion == '0.96':
                     field = self.webkit.TextField(
                         field_name=metaAttr.name,
                         is_required=isFieldRequired,
@@ -302,7 +364,9 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
         elif metaAttr.typeName == 'ImageFile':
-            if webkitName == 'django':
+            if webkitName == 'django' and webkitVersion == '1.0':
+                raise Exception("No field yet.")
+            elif webkitName == 'django' and webkitVersion == '0.96':
                 field = self.webkit.FileUploadField(
                     field_name=metaAttr.name,
                     is_required=isFieldRequired,
@@ -313,11 +377,19 @@ class DomainObjectManipulator(BaseManipulator):
                         size=40
                     )
         if field:
-            if webkitName == 'django':
+            if webkitName == 'django' and webkitVersion == '1.0':
+                field.metaAttr = metaAttr
+                field.field_name = metaAttr.name
+                field.field_title = metaAttr.calcTitle()
+                field.field_comment = metaAttr.comment
+                self.fields[metaAttr.name] = field
+            elif webkitName == 'django' and webkitVersion == '0.96':
                 field.metaAttr = metaAttr
                 field.field_title = metaAttr.calcTitle()
                 field.field_comment = metaAttr.comment
-            self.fields.append(field)
+                self.fields.append(field)
+            elif webkitName == 'pylons':
+                self.fields.append(field)
         else:
             message = "No form field for meta attribute: %s" % metaAttr
             self.logger.critical(message)
@@ -332,15 +404,11 @@ class DomainObjectManipulator(BaseManipulator):
         
     def createObjectKwds(self):
         self.objectKwds = {}
-        for metaAttr in self.metaObject.attributes:
-            if not metaAttr.isAssociateList:
-                # Todo: Fix this up to check the fields like update().
-                if self.data.has_key(metaAttr.name):
-                    attrValue = metaAttr.makeValueFromMultiValueDict(
-                        self.data
-                    )
-                    if not attrValue == None:
-                        self.objectKwds[metaAttr.name] = attrValue
+        fieldedAttrs = self.getFieldedMetaAttrs()
+        domValues = self.presentationToDomainValues(self.data, fieldedAttrs)
+        for (attrName, domValue) in domValues.items():
+            if not domValue == None:
+                self.objectKwds[attrName] = domValue
 
     def createDomainObject(self):
         commandClass = self.getCreateCommandClass()
@@ -371,6 +439,30 @@ class DomainObjectManipulator(BaseManipulator):
             return self.commands[className]
         return None
 
+    def getFieldedMetaAttrs(self):
+        metaAttrs = {}
+        for metaAttr in self.metaObject.attributes:
+            if not metaAttr.isAssociateList:
+                if metaAttr.name in self.fieldNames:
+                    if metaAttr.name in self.data:
+                        metaAttrs[metaAttr.name] = metaAttr
+        return metaAttrs
+
+    # Todo: Rename MultiValueDict as PresentationObject.
+    def presentationToDomainValues(self, multiValueDict, fieldedAttrs):
+        domValues = {}
+        for (attrName, metaAttr) in fieldedAttrs.items():
+            try:
+                domValue = metaAttr.makeValueFromMultiValueDict(multiValueDict)
+                domValues[attrName] = domValue
+            except Exception, inst:
+                msg = "Can't make '%s' value from multi-value dict: %s" % (
+                    attrName, multiValueDict
+                )
+                self.logger.error(msg)
+                raise
+        return domValues
+
     def update(self, data):
         self.data = data
         self.setNonAssociateListAttributes()
@@ -381,26 +473,10 @@ class DomainObjectManipulator(BaseManipulator):
         self.domainObject.save()
        
     def setAttributesFromMultiValueDict(self, domainObject, multiValueDict):
-        attrValues = {}
-        metaAttrs = {}
-        for metaAttr in self.metaObject.attributes:
-            if not metaAttr.isAssociateList:
-                if metaAttr.name in self.fieldNames:
-                    if metaAttr.name in self.data:
-                        metaAttrs[metaAttr.name] = metaAttr
-        for attrName in metaAttrs:
-            metaAttr = metaAttrs[attrName]
-            try:
-                domValue = metaAttr.makeValueFromMultiValueDict(multiValueDict)
-                attrValues[attrName] = domValue
-            except Exception, inst:
-                msg = "Can't make '%s' value from multi-value dict: %s" % (
-                    attrName, multiValueDict
-                )
-                self.logger.error(msg)
-                raise
-        for attrName in metaAttrs:
-            metaAttr = metaAttrs[attrName]
+        fieldedAttrs = self.getFieldedMetaAttrs()
+        attrValues = self.presentationToDomainValues(multiValueDict, fieldedAttrs)
+        for attrName in fieldedAttrs:
+            metaAttr = fieldedAttrs[attrName]
             attrValue = attrValues[attrName]
             if attrValue != metaAttr.getAttributeValue(domainObject):
                 msg = "Setting '%s' attribute to '%s'." % (attrName, attrValue)
@@ -426,7 +502,10 @@ class DomainObjectManipulator(BaseManipulator):
         return None
 
     def getUpdateParams(self):
-        return self.domainObject.asRequestParams()
+        initialParams = self.domainObject.asRequestParams()
+        if webkitName == 'django' and webkitVersion == '1.0':
+            self.initial = initialParams
+        return initialParams
 
 
 class HasManyManipulator(DomainObjectManipulator):
@@ -472,15 +551,21 @@ class FormWrapper(object):
 
     def wrapManipulatorFields(self):
         wrappedFields = []
-        for field in self.manipulator.fields: 
-            if hasattr(field, 'requires_data_list') and hasattr(self.data, 'getlist'):
-                data = self.data.getlist(field.field_name)
-            else:
-                data = self.data.get(field.field_name, None)
-            if data is None:
-                data = ''
-            wrappedField = FormFieldWrapper(field, data, self.error_dict.get(field.field_name, []))
-            wrappedFields.append(wrappedField)
+        if webkitName == 'django' and webkitVersion == '1.0':
+            for fieldName in self.manipulator.fields.keys():
+                boundField = self.manipulator.__getitem__(fieldName)
+                wrappedField = self.wrapField(fieldName, boundField)
+                wrappedFields.append(wrappedField)
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            for field in self.manipulator.fields:
+                if hasattr(field, 'requires_data_list') and hasattr(self.data, 'getlist'):
+                    data = self.data.getlist(field.field_name)
+                else:
+                    data = self.data.get(field.field_name, None)
+                if data is None:
+                    data = ''
+                wrappedField = FormFieldWrapper(field, data, self.error_dict.get(field.field_name, []))
+                wrappedFields.append(wrappedField)
         return wrappedFields
 
     def wrapPluginFields(self):
@@ -502,16 +587,30 @@ class FormWrapper(object):
 
         return wrappedFields
 
+    def wrapField(self, fieldName, field): 
+        field.field_name = fieldName
+        data = self.data.get(fieldName, None)
+        if data is None:
+            data = ''
+        error_list = self.error_dict.get(fieldName, [])
+        return FormFieldWrapper(field, data, error_list)
+
     def __getitem__(self, key):
-        for field in self.manipulator.fields:
-            if field.field_name == key:
-                if hasattr(field, 'requires_data_list') and hasattr(self.data, 'getlist'):
-                    data = self.data.getlist(field.field_name)
-                else:
-                    data = self.data.get(field.field_name, None)
-                if data is None:
-                    data = ''
-                return FormFieldWrapper(field, data, self.error_dict.get(field.field_name, []))
+        if webkitName == 'django' and webkitVersion == '1.0':
+            fieldName = key
+            boundField = self.manipulator.__getitem__(fieldName)
+            return self.wrapField(fieldName, boundField)
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            for field in self.manipulator.fields:
+                if field.field_name == key:
+                    if hasattr(field, 'requires_data_list') and hasattr(self.data, 'getlist'):
+                        data = self.data.getlist(field.field_name)
+                    else:
+                        data = self.data.get(field.field_name, None)
+                    if data is None:
+                        data = ''
+                    error_list = self.error_dict.get(field.field_name, [])
+                    return FormFieldWrapper(field, data, error_list)
         raise KeyError
 
     def has_errors(self):
@@ -524,33 +623,64 @@ class FormFieldWrapper(object):
     def __init__(self, formfield, data, error_list):
         self.formfield, self.data, self.error_list = formfield, data, error_list
         self.field_name = self.formfield.field_name
-        if hasattr(self.formfield, 'field_title'):
-            self.field_title = self.formfield.field_title
-        if hasattr(self.formfield, 'field_comment'):
-            self.field_comment = self.formfield.field_comment
+        if webkitName == 'django' and webkitVersion == '1.0':
+            if hasattr(self.formfield.field, 'field_title'):
+                self.field_title = self.formfield.field.field_title
+            if hasattr(self.formfield.field, 'field_comment'):
+                self.field_comment = self.formfield.field.field_comment
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            if hasattr(self.formfield, 'field_title'):
+                self.field_title = self.formfield.field_title
+            if hasattr(self.formfield, 'field_comment'):
+                self.field_comment = self.formfield.field_comment
         self.error = self.makeErrorMessage()
 
     def makeErrorMessage(self):
-        if len(self.error_list):
-            message =  htmlescape(self.error_list[0])
-            thisFieldPattern = re.compile('This field')
-            confirmationPattern = re.compile('confirmation')
-            underscorePattern = re.compile('_')
-            fieldName = self.field_name
-            message = thisFieldPattern.sub(fieldName.capitalize(), message)
-            message = confirmationPattern.sub(' confirmation', message)
-            message = underscorePattern.sub(' ', message)
-            return message
-        else:
-            return ''
+        message = ''
+        if webkitName == 'django' and webkitVersion == '1.0':
+            if len(self.error_list):
+                from django.utils.html import conditional_escape
+                from django.utils.encoding import force_unicode
+                from django.utils.safestring import mark_safe
+                message = mark_safe(conditional_escape(force_unicode(self.error_list[0])))
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            if len(self.error_list):
+                message =  htmlescape(self.error_list[0])
+        thisFieldPattern = re.compile('This field')
+        thisValuePattern = re.compile('this value')
+        validValuePattern = re.compile('valid value')
+        confirmationPattern = re.compile('confirmation')
+        underscorePattern = re.compile('_')
+        fieldName = self.field_name
+        message = thisFieldPattern.sub(fieldName.capitalize(), message)
+        message = thisValuePattern.sub(fieldName, message)
+        message = validValuePattern.sub('valid '+fieldName, message)
+        message = confirmationPattern.sub(' confirmation', message)
+        message = underscorePattern.sub(' ', message)
+        return message
+
+    def __unicode__(self):
+        if webkitName == 'django' and webkitVersion == '1.0':
+            from django.utils.html import conditional_escape
+            from django.utils.encoding import force_unicode
+            from django.utils.safestring import mark_safe
+            html = (force_unicode(self.formfield))
+            if self.error_list:
+                html = u'<div class="field-with-error">' + html + u'</div>'
+            return mark_safe(html)
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            return self.__str__()
 
     def __str__(self):
         "Renders the field"
-        html = str(self.formfield.render(self.data))
-        if self.error_list:
-            return '<div class="field-with-error">' + html + '</div>'
-        else:
-            return html
+        if webkitName == 'django' and webkitVersion == '1.0':
+            return self.__unicode__()
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            html = str(self.formfield.render(self.data))
+            if self.error_list:
+                return '<div class="field-with-error">' + html + '</div>'
+            else:
+                return html
 
     def __repr__(self):
         return '<FormFieldWrapper for "%s">' % self.formfield.field_name
@@ -566,8 +696,11 @@ class FormFieldWrapper(object):
         return self.error_list
 
     def html_error_list(self):
-        if self.errors():
-            return '<ul class="errorlist"><li>%s</li></ul>' % '</li><li>'.join([htmlescape(e) for e in self.errors()])
-        else: 
-            return ''
+        if webkitName == 'django' and webkitVersion == '1.0':
+            return self.errors_list.as_ul()
+        elif webkitName == 'django' and webkitVersion == '0.96':
+            if self.errors_list:
+                return '<ul class="errorlist"><li>%s</li></ul>' % '</li><li>'.join([htmlescape(e) for e in self.errors_list])
+            else: 
+                return ''
 
