@@ -10,21 +10,42 @@ if not webkitName:
     pass
 elif webkitName == 'django':
     import django
-    from django.utils.html import escape as htmlescape
-    from django.forms import validators
-    from django.forms import Manipulator
-    from django.forms import SelectField, SelectMultipleField, TextField
-    from django.forms import TextField, LargeTextField
-    from django.forms import PasswordField, IntegerField, SmallIntegerField
-    from django.forms import PositiveIntegerField, URLField, CheckboxField
-    from django.forms import DatetimeField, DateField, TimeField
-    from django.forms import FileUploadField, EmailField, RadioSelectField
-    from django.core.validators import ValidationError
-    from django.template import Context
-    from django.core import template_loader
-    from django.http import HttpRequest
-    from django.http import HttpResponse
-    from django.http import HttpResponseRedirect
+    import django.forms
+    if hasattr(django.forms, 'BaseForm'): # Django 1.0
+        webkitVersion = '1.0'
+        from django.forms.forms import BaseForm
+        class Manipulator(BaseForm): pass
+        from django.forms.util import ValidationError
+        from django.utils.html import escape as htmlescape
+        from django.http import HttpRequest
+        from django.http import HttpResponse
+        from django.http import HttpResponseRedirect
+        from django.template import Context
+        from django.core import template_loader
+        from django.forms import Field
+        from django.forms import EmailField
+        from django.forms import ChoiceField
+        from django.forms import DateTimeField
+        from django.forms import widgets
+        from django.forms import fields
+        from django.utils.datastructures import SortedDict
+    else:                             # Django 0.96
+        webkitVersion = '0.96'
+        from django.utils.html import escape as htmlescape
+        from django.forms import validators
+        from django.forms import Manipulator
+        from django.forms import SelectField, SelectMultipleField, TextField
+        from django.forms import TextField, LargeTextField
+        from django.forms import PasswordField, IntegerField, SmallIntegerField
+        from django.forms import PositiveIntegerField, URLField, CheckboxField
+        from django.forms import DatetimeField, DateField, TimeField
+        from django.forms import FileUploadField, EmailField, RadioSelectField
+        from django.core.validators import ValidationError
+        from django.template import Context
+        from django.core import template_loader
+        from django.http import HttpRequest
+        from django.http import HttpResponse
+        from django.http import HttpResponseRedirect
 
 elif webkitName == 'pylons':
     import pylons
@@ -59,7 +80,7 @@ else:
 ## Django extensions, without a home. Perhaps push back into ScanBooker?
 #
 
-if webkitName == 'django':
+if webkitName == 'django' and webkitVersion == '0.96':
 
     import sre
     _rdatere = r'((?:0?[1-9])|(?:[12][0-9])|(?:3[0-1]))-((?:0?[1-9])|(?:1[0-2]))-(19|2\d)\d{2}'
